AWS provides S3 web service storage to store and retrieve data easily.
Access to the S3 bucket can enable access control and implement a few security
settings. S3 bucket has been behind several high-profile data
compromises and is a common misconfiguration.

A publicly accessible AWS S3 bucket was detected with potentially
sensitive information. The information was detected as the bucket
enables file listing, and an attacker can navigate all content in the
bucket.
